@@ -32,6 +32,7 @@ from security.decorators import log_with_data
 from security.enums import CeleryTaskInvocationLogState, CeleryTaskRunLogState, LoggerName
 from security.backends.sql.models import CeleryTaskRunLog as SQLCeleryTaskRunLog
 from security.backends.sql.models import CeleryTaskInvocationLog as SQLCeleryTaskInvocationLog
+from security.backends.elasticsearch.tests import store_elasticsearch_log
 from security.backends.elasticsearch.models import CeleryTaskRunLog as ElasticsearchCeleryTaskRunLog
 from security.backends.elasticsearch.models import CeleryTaskInvocationLog as ElasticsearchCeleryTaskInvocationLog
 from security.backends.signals import (
@@ -45,7 +46,7 @@ from security.utils import get_object_triple
 
 from apps.test_security.tasks import error_task, retry_task, sum_task, unique_task, ignored_after_success_task
 
-from .base import BaseTestCaseMixin, TRUNCATION_CHAR, test_call_command, assert_equal_logstash
+from .base import BaseTestCaseMixin, TRUNCATION_CHAR, test_call_command, assert_equal_logstash, assert_equal_log_data
 
 
 @override_settings(SECURITY_BACKEND_WRITERS={})
@@ -72,8 +73,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             'stale_at': None,
             'estimated_time_of_first_arrival': not_none_eq_obj,
             'expires_at': None,
-            'celery_task_id': not_none_eq_obj,
-            'is_duplicate': False,
+            'celery_task_id': not_none_eq_obj
         }
 
         expected_run_started_data = {
@@ -101,10 +101,10 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             assert_length_equal(logged_data.celery_task_run_succeeded, 1)
             assert_length_equal(logged_data.celery_task_run_failed, 0)
             assert_length_equal(logged_data.celery_task_run_retried, 0)
-            assert_equal(logged_data.celery_task_invocation_started[0].data, expected_invocation_started_data)
-            assert_equal(logged_data.celery_task_invocation_triggered[0].data, expected_invocation_triggered_data)
-            assert_equal(logged_data.celery_task_run_started[0].data, expected_run_started_data)
-            assert_equal(logged_data.celery_task_run_succeeded[0].data, expected_run_succeeded_data)
+            assert_equal_log_data(logged_data.celery_task_invocation_started[0], expected_invocation_started_data)
+            assert_equal_log_data(logged_data.celery_task_invocation_triggered[0], expected_invocation_triggered_data)
+            assert_equal_log_data(logged_data.celery_task_run_started[0], expected_run_started_data)
+            assert_equal_log_data(logged_data.celery_task_run_succeeded[0], expected_run_succeeded_data)
             assert_equal(logged_data.celery_task_invocation[0].related_objects, {get_object_triple(user)})
             assert_equal(
                 get_logs_related_with_object(LoggerName.CELERY_TASK_INVOCATION, user),
@@ -131,7 +131,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             'estimated_time_of_first_arrival': not_none_eq_obj,
             'expires_at': None,
             'celery_task_id': not_none_eq_obj,
-            'is_duplicate': False,
         }
 
         expected_run_started_data = {
@@ -158,10 +157,10 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             assert_length_equal(logged_data.celery_task_run_succeeded, 0)
             assert_length_equal(logged_data.celery_task_run_failed, 1)
             assert_length_equal(logged_data.celery_task_run_retried, 0)
-            assert_equal(logged_data.celery_task_invocation_started[0].data, expected_invocation_started_data)
-            assert_equal(logged_data.celery_task_invocation_triggered[0].data, expected_invocation_triggered_data)
-            assert_equal(logged_data.celery_task_run_started[0].data, expected_run_started_data)
-            assert_equal(logged_data.celery_task_run_failed[0].data, expected_run_failed_data)
+            assert_equal_log_data(logged_data.celery_task_invocation_started[0], expected_invocation_started_data)
+            assert_equal_log_data(logged_data.celery_task_invocation_triggered[0], expected_invocation_triggered_data)
+            assert_equal_log_data(logged_data.celery_task_run_started[0], expected_run_started_data)
+            assert_equal_log_data(logged_data.celery_task_run_failed[0], expected_run_failed_data)
 
     def test_retry_celery_task_should_be_logged(self):
         expected_invocation_started_data = {
@@ -183,7 +182,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             'estimated_time_of_first_arrival': not_none_eq_obj,
             'expires_at': None,
             'celery_task_id': not_none_eq_obj,
-            'is_duplicate': False,
         }
 
         expected_run_started_data = {
@@ -213,10 +211,10 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             assert_length_equal(logged_data.celery_task_run_succeeded, 1)
             assert_length_equal(logged_data.celery_task_run_failed, 0)
             assert_length_equal(logged_data.celery_task_run_retried, 5)
-            assert_equal(logged_data.celery_task_invocation_started[0].data, expected_invocation_started_data)
-            assert_equal(logged_data.celery_task_invocation_triggered[0].data, expected_invocation_triggered_data)
-            assert_equal(logged_data.celery_task_run_started[0].data, expected_run_started_data)
-            assert_equal(logged_data.celery_task_run_retried[0].data, expected_run_retried_data)
+            assert_equal_log_data(logged_data.celery_task_invocation_started[0], expected_invocation_started_data)
+            assert_equal_log_data(logged_data.celery_task_invocation_triggered[0], expected_invocation_triggered_data)
+            assert_equal_log_data(logged_data.celery_task_run_started[0], expected_run_started_data)
+            assert_equal_log_data(logged_data.celery_task_run_retried[0], expected_run_retried_data)
 
     @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, SECURITY_TASK_USE_ON_SUCCESS=True)
     def test_ignored_after_success_celery_task_should_be_logged(self):
@@ -258,10 +256,9 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             apply_method.return_value = unique_task_id
             with capture_security_logs() as logged_data:
                 unique_task.apply_async()
-                assert_length_equal(logged_data.celery_task_invocation_triggered, 1)
+                assert_length_equal(logged_data.celery_task_invocation_duplicate, 1)
                 assert_length_equal(logged_data.celery_task_run_started, 0)
-                assert_true(logged_data.celery_task_invocation_triggered[0].data['is_duplicate'])
-                assert_equal(logged_data.celery_task_invocation_triggered[0].data['celery_task_id'], unique_task_id)
+                assert_equal(logged_data.celery_task_invocation_duplicate[0].celery_task_id, unique_task_id)
 
     def test_data_change_should_be_connected_with_celery_task_run_log(self):
         with capture_security_logs() as logged_data:
@@ -288,7 +285,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 time=(sql_celery_task_invocation_log.stop - sql_celery_task_invocation_log.start).total_seconds(),
                 stale_at=None,
                 expires_at=None,
-                is_duplicate=False,
                 input='5, 8',
                 task_args=[5, 8],
                 task_kwargs={},
@@ -331,7 +327,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     ).total_seconds(),
                     stale_at=None,
                     expires_at=None,
-                    is_duplicate=False,
                     input='5, 8',
                     task_args='[5, 8]',
                     task_kwargs='{}',
@@ -356,7 +351,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     retries=0
                 )
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, SECURITY_ELASTICSEARCH_LOGSTASH_WRITER=True)
+    @store_elasticsearch_log(SECURITY_ELASTICSEARCH_LOGSTASH_WRITER=True)
     @data_consumer('create_user')
     def test_sum_celery_task_should_be_logged_in_elasticsearch_backend_through_logstash(self, user):
         with log_with_data(related_objects=[user]):
@@ -367,8 +362,8 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     celery_task_invocation_log = logged_data.celery_task_invocation[0]
                     celery_task_run_log = logged_data.celery_task_run[0]
 
-                    assert_equal(len(cm.output), 4)
-                    start_invocation, trigger_invocation, start_run, success_run = cm.output
+                    assert_equal(len(cm.output), 5)
+                    start_invocation, trigger_invocation, start_run, success_run, success_invocation = cm.output
 
                     start_invocation_expected_data = {
                         'slug': None,
@@ -393,11 +388,15 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                         'triggered_at': not_none_eq_obj,
                         'state': 'TRIGGERED',
                         'stale_at': None,
-                        'is_duplicate': False,
                         'celery_task_id': not_none_eq_obj,
                         'estimated_time_of_first_arrival': not_none_eq_obj,
                         'expires_at': None,
                     }
+                    success_invocation_expected_data ={
+                        **trigger_invocation_expected_data,
+                        'state': 'SUCCEEDED',
+                        'stop': not_none_eq_obj,
+                    }
 
                     start_run_expected_data = {
                         'slug': None,
@@ -453,6 +452,13 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                         celery_task_run_log.id,
                         success_run_expected_data
                     )
+                    assert_equal_logstash(
+                        success_invocation,
+                        'security-celery-task-invocation-log',
+                        9999,
+                        celery_task_invocation_log.id,
+                        success_invocation_expected_data
+                    )
 
     @override_settings(SECURITY_BACKEND_WRITERS={'logging'})
     def test_sum_celery_task_should_be_logged_in_logging_backend(self):
@@ -465,14 +471,18 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     [
                         f'INFO:security.celery:'
                         f'Celery task invocation "{logged_data.celery_task_invocation[0].id}" '
-                        f'with celery id "{logged_data.celery_task_invocation[0].data["celery_task_id"]}" '
+                        f'with celery id "{logged_data.celery_task_invocation[0].celery_task_id}" '
                         f'and name "sum_task" was invoked',
                         f'INFO:security.celery:Celery task "{logged_data.celery_task_run[0].id}" with '
-                        f'celery id "{logged_data.celery_task_run[0].data["celery_task_id"]}" and name "sum_task" '
+                        f'celery id "{logged_data.celery_task_run[0].celery_task_id}" and name "sum_task" '
                         f'was started',
                         f'INFO:security.celery:Celery task "{logged_data.celery_task_run[0].id}" with '
-                        f'celery id "{logged_data.celery_task_run[0].data["celery_task_id"]}" and name "sum_task" '
+                        f'celery id "{logged_data.celery_task_run[0].celery_task_id}" and name "sum_task" '
                         f'was successful',
+                        f'INFO:security.celery:'
+                        f'Celery task invocation "{logged_data.celery_task_invocation[0].id}" '
+                        f'with celery id "{logged_data.celery_task_invocation[0].celery_task_id}" '
+                        f'and name "sum_task" was successful',
                     ]
                 )
 
@@ -490,7 +500,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             name='error_task',
             time=(sql_celery_task_invocation_log.stop - sql_celery_task_invocation_log.start).total_seconds(),
             expires_at=None,
-            is_duplicate=False,
             input='',
             task_args=[],
             task_kwargs={},
@@ -510,7 +519,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
         )
         assert_is_not_none(sql_celery_task_run_log.error_message)
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'})
+    @store_elasticsearch_log()
     def test_error_celery_task_should_be_logged_in_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             error_task.apply()
@@ -530,7 +539,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     elasticsearch_celery_task_invocation_log.stop - elasticsearch_celery_task_invocation_log.start
                 ).total_seconds(),
                 expires_at=None,
-                is_duplicate=False,
                 input='',
                 task_args='[]',
                 task_kwargs='{}',
@@ -550,7 +558,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             )
             assert_is_not_none(elasticsearch_celery_task_run_log.error_message)
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, SECURITY_ELASTICSEARCH_LOGSTASH_WRITER=True)
+    @store_elasticsearch_log(SECURITY_ELASTICSEARCH_LOGSTASH_WRITER=True)
     def test_error_celery_task_should_be_logged_in_elasticsearch_backend_through_logstash(self):
         with capture_security_logs() as logged_data:
             with self.assertLogs('security.logstash', level='INFO') as cm:
@@ -558,8 +566,8 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 celery_task_invocation_log = logged_data.celery_task_invocation[0]
                 celery_task_run_log = logged_data.celery_task_run[0]
 
-                assert_equal(len(cm.output), 4)
-                start_invocation, trigger_invocation, start_run, failed_run = cm.output
+                assert_equal(len(cm.output), 5)
+                start_invocation, trigger_invocation, start_run, failed_run, failed_invocation = cm.output
 
                 start_invocation_expected_data = {
                     'slug': None,
@@ -584,11 +592,14 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     'triggered_at': not_none_eq_obj,
                     'state': 'TRIGGERED',
                     'stale_at': not_none_eq_obj,
-                    'is_duplicate': False,
                     'celery_task_id': not_none_eq_obj,
                     'estimated_time_of_first_arrival': not_none_eq_obj,
                     'expires_at': None,
                 }
+                failed_invocation_expected_data = {
+                    **trigger_invocation_expected_data,
+                    'state': 'FAILED'
+                }
 
                 start_run_expected_data = {
                     'slug': None,
@@ -644,7 +655,13 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     celery_task_run_log.id,
                     failed_run_expected_data
                 )
-
+                assert_equal_logstash(
+                    failed_invocation,
+                    'security-celery-task-invocation-log',
+                    9999,
+                    celery_task_invocation_log.id,
+                    failed_invocation_expected_data
+                )
 
     @override_settings(SECURITY_BACKEND_WRITERS={'logging'})
     def test_error_celery_task_should_be_logged_in_logging_backend(self):
@@ -657,14 +674,18 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     [
                         f'INFO:security.celery:'
                         f'Celery task invocation "{logged_data.celery_task_invocation[0].id}" '
-                        f'with celery id "{logged_data.celery_task_invocation[0].data["celery_task_id"]}" '
+                        f'with celery id "{logged_data.celery_task_invocation[0].celery_task_id}" '
                         f'and name "error_task" was invoked',
                         f'INFO:security.celery:Celery task "{logged_data.celery_task_run[0].id}" with '
-                        f'celery id "{logged_data.celery_task_run[0].data["celery_task_id"]}" and name "error_task" '
+                        f'celery id "{logged_data.celery_task_run[0].celery_task_id}" and name "error_task" '
                         f'was started',
                         f'ERROR:security.celery:Celery task "{logged_data.celery_task_run[0].id}" with '
-                        f'celery id "{logged_data.celery_task_run[0].data["celery_task_id"]}" and name "error_task" '
+                        f'celery id "{logged_data.celery_task_run[0].celery_task_id}" and name "error_task" '
                         f'failed',
+                        f'INFO:security.celery:'
+                        f'Celery task invocation "{logged_data.celery_task_invocation[0].id}" '
+                        f'with celery id "{logged_data.celery_task_invocation[0].celery_task_id}" '
+                        f'and name "error_task" was failed',
                     ]
                 )
 
@@ -682,7 +703,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 name='retry_task',
                 time=(sql_celery_task_invocation_log.stop - sql_celery_task_invocation_log.start).total_seconds(),
                 expires_at=None,
-                is_duplicate=False,
                 input='',
                 task_args=[],
                 task_kwargs={},
@@ -718,7 +738,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             )
             assert_equal(sql_celery_task_invocation_log.last_run.id, sql_celery_task_run_log.id)
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'})
+    @store_elasticsearch_log()
     def test_retry_celery_task_should_be_logged_in_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             retry_task.apply()
@@ -734,7 +754,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     elasticsearch_celery_task_invocation_log.stop - elasticsearch_celery_task_invocation_log.start
                 ).total_seconds(),
                 expires_at=None,
-                is_duplicate=False,
                 input='',
                 task_args='[]',
                 task_kwargs='{}',
@@ -777,14 +796,14 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             ElasticsearchCeleryTaskRunLog._index.refresh()
             assert_equal(elasticsearch_celery_task_invocation_log.last_run.id, elasticsearch_celery_task_run_log.id)
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, SECURITY_ELASTICSEARCH_LOGSTASH_WRITER=True)
+    @store_elasticsearch_log(SECURITY_ELASTICSEARCH_LOGSTASH_WRITER=True)
     def test_retry_celery_task_should_be_logged_in_elasticsearch_backend_through_logstash(self):
         with capture_security_logs() as logged_data:
             with self.assertLogs('security.logstash', level='INFO') as cm:
                 retry_task.apply()
                 celery_task_invocation_log = logged_data.celery_task_invocation[0]
 
-                assert_equal(len(cm.output), 14)
+                assert_equal(len(cm.output), 15)
                 start_invocation, trigger_invocation = cm.output[:2]
 
                 start_invocation_expected_data = {
@@ -810,7 +829,6 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     'triggered_at': not_none_eq_obj,
                     'state': 'TRIGGERED',
                     'stale_at': None,
-                    'is_duplicate': False,
                     'celery_task_id': not_none_eq_obj,
                     'estimated_time_of_first_arrival': not_none_eq_obj,
                     'expires_at': None,
@@ -914,6 +932,19 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     succes_run_expected_data
                 )
 
+                success_invocation = cm.output[14]
+                success_invocation_expected_data = {
+                    **trigger_invocation_expected_data,
+                    'state': 'SUCCEEDED',
+                }
+                assert_equal_logstash(
+                    success_invocation,
+                    'security-celery-task-invocation-log',
+                    9999,
+                    celery_task_invocation_log.id,
+                    success_invocation_expected_data
+                )
+
     @override_settings(SECURITY_BACKEND_WRITERS={'logging'})
     def test_retry_celery_task_should_be_logged_in_logging_backend(self):
         with capture_security_logs() as logged_data:
@@ -922,25 +953,29 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 expected_output = [
                     f'INFO:security.celery:'
                     f'Celery task invocation "{logged_data.celery_task_invocation[0].id}" '
-                    f'with celery id "{logged_data.celery_task_invocation[0].data["celery_task_id"]}" '
+                    f'with celery id "{logged_data.celery_task_invocation[0].celery_task_id}" '
                     f'and name "retry_task" was invoked',
                 ]
                 for logger in logged_data.celery_task_run[0:5]:
                     expected_output += [
                         f'INFO:security.celery:Celery task "{logger.id}" with '
-                        f'celery id "{logger.data["celery_task_id"]}" and name "retry_task" '
+                        f'celery id "{logger.celery_task_id}" and name "retry_task" '
                         f'was started',
                         f'WARNING:security.celery:Celery task "{logger.id}" with '
-                        f'celery id "{logger.data["celery_task_id"]}" and name "retry_task" '
+                        f'celery id "{logger.celery_task_id}" and name "retry_task" '
                         f'was repeated',
                     ]
                 expected_output += [
                     f'INFO:security.celery:Celery task "{logged_data.celery_task_run[-1].id}" with '
-                    f'celery id "{logged_data.celery_task_run[-1].data["celery_task_id"]}" and name "retry_task" '
+                    f'celery id "{logged_data.celery_task_run[-1].celery_task_id}" and name "retry_task" '
                     f'was started',
                     f'INFO:security.celery:Celery task "{logged_data.celery_task_run[-1].id}" with '
-                    f'celery id "{logged_data.celery_task_run[-1].data["celery_task_id"]}" and name "retry_task" was '
+                    f'celery id "{logged_data.celery_task_run[-1].celery_task_id}" and name "retry_task" was '
                     f'successful',
+                    f'INFO:security.celery:'
+                    f'Celery task invocation "{logged_data.celery_task_invocation[0].id}" '
+                    f'with celery id "{logged_data.celery_task_invocation[0].celery_task_id}" '
+                    f'and name "retry_task" was successful',
                 ]
                 assert_equal(cm.output, expected_output)
 
@@ -952,18 +987,22 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             unique_task.apply_async()
 
             sql_celery_task_invocation_log = SQLCeleryTaskInvocationLog.objects.get()
+            assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.DUPLICATE)
+
             test_call_command('set_celery_task_log_state')
             sql_celery_task_invocation_log.refresh_from_db()
-            assert_equal(
-                sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.TRIGGERED
-            )
+            assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.DUPLICATE)
+
+            change_and_save(sql_celery_task_invocation_log, state=CeleryTaskInvocationLogState.TRIGGERED, version=5)
+            test_call_command('set_celery_task_log_state')
+            assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.TRIGGERED)
 
             with freeze_time(now() + timedelta(seconds=30)):
                 test_call_command('set_celery_task_log_state')
                 sql_celery_task_invocation_log.refresh_from_db()
                 assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.EXPIRED)
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
+    @store_elasticsearch_log(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_failed_with_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             with mock.patch.object(unique_task, '_get_unique_task_id') as apply_method:
@@ -976,17 +1015,25 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 assert_equal(
                     ElasticsearchCeleryTaskInvocationLog.get(
                         id=logged_data.celery_task_invocation[0].id
-                    ).state, CeleryTaskInvocationLogState.TRIGGERED
+                    ).state, CeleryTaskInvocationLogState.DUPLICATE
                 )
 
-                with freeze_time(now() + timedelta(seconds=30)):
-                    test_call_command('set_celery_task_log_state')
-                    assert_equal(
-                        ElasticsearchCeleryTaskInvocationLog.get(
-                            id=logged_data.celery_task_invocation[0].id
-                        ).state,
-                        CeleryTaskInvocationLogState.EXPIRED
-                    )
+                # Update index increase version over the maximum
+                with mock.patch('security.backends.elasticsearch.writer.MAX_VERSION', 10001):
+                    ElasticsearchCeleryTaskInvocationLog.get(
+                        id=logged_data.celery_task_invocation[0].id
+                    ).update(state=CeleryTaskInvocationLogState.TRIGGERED)
+                    ElasticsearchCeleryTaskInvocationLog._index.refresh()
+                    ElasticsearchCeleryTaskRunLog._index.refresh()
+
+                    with freeze_time(now() + timedelta(seconds=30)):
+                        test_call_command('set_celery_task_log_state')
+                        assert_equal(
+                            ElasticsearchCeleryTaskInvocationLog.get(
+                                id=logged_data.celery_task_invocation[0].id
+                            ).state,
+                            CeleryTaskInvocationLogState.EXPIRED
+                        )
 
     @override_settings(SECURITY_BACKEND_WRITERS={'sql'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_succeeded_with_sql_backend(self):
@@ -1006,7 +1053,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             sql_celery_task_invocation_log.refresh_from_db()
             assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.SUCCEEDED)
 
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
+    @store_elasticsearch_log(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_succeeded_with_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             unique_task.apply_async()
@@ -1016,18 +1063,20 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             ElasticsearchCeleryTaskInvocationLog._index.refresh()
             ElasticsearchCeleryTaskRunLog._index.refresh()
 
-            test_call_command('set_celery_task_log_state')
-            assert_equal(
-                ElasticsearchCeleryTaskInvocationLog.get(
-                    id=logged_data.celery_task_invocation[0].id
-                ).state, CeleryTaskInvocationLogState.TRIGGERED
-            )
-
-            with freeze_time(now() + timedelta(seconds=30)):
+            # Update index increase version over the maximum
+            with mock.patch('security.backends.elasticsearch.writer.MAX_VERSION', 10001):
                 test_call_command('set_celery_task_log_state')
                 assert_equal(
                     ElasticsearchCeleryTaskInvocationLog.get(
                         id=logged_data.celery_task_invocation[0].id
-                    ).state,
-                    CeleryTaskInvocationLogState.SUCCEEDED
+                    ).state, CeleryTaskInvocationLogState.TRIGGERED
                 )
+
+                with freeze_time(now() + timedelta(seconds=30)):
+                    test_call_command('set_celery_task_log_state')
+                    assert_equal(
+                        ElasticsearchCeleryTaskInvocationLog.get(
+                            id=logged_data.celery_task_invocation[0].id
+                        ).state,
+                        CeleryTaskInvocationLogState.SUCCEEDED
+                    )
